@@ -28,19 +28,19 @@
 #include "lssi.h"
 #include "nullable.h"
 
-typedef struct parse_state
+struct parse_state
 {
-  // path of state-items the parser has traversed
+  // Path of state-items the parser has traversed.
   struct si_chunk
   {
-    // elements newly added in this chunk
+    // Elements newly added in this chunk.
     state_item_list contents;
-    // properties of the linked list this chunk represents
+    // Properties of the linked list this chunk represents.
     const state_item *head_elt;
     const state_item *tail_elt;
     size_t total_size;
   } state_items;
-  // list of derivations of the symbols
+  // List of derivations of the symbols.
   struct deriv_chunk
   {
     derivation_list contents;
@@ -50,18 +50,15 @@ typedef struct parse_state
   } derivs;
   struct parse_state *parent;
   int reference_count;
-  // incremented during productions,
-  // decremented during reductions
+  // Incremented during productions, decremented during reductions.
   int depth;
-  // whether the contents of the chunks should be
-  // prepended or appended to the list the chunks
-  // represent
+  // Whether the contents of the chunks should be prepended or
+  // appended to the list the chunks represent.
   bool prepend;
-  // causes chunk contents to be freed when the
-  // reference count is one. Used when only the chunk metadata
-  // will be needed.
+  // Causes chunk contents to be freed when the reference count is
+  // one. Used when only the chunk metadata will be needed.
   bool free_contents_early;
-} parse_state;
+};
 
 
 static void
@@ -438,9 +435,8 @@ simulate_transition (parse_state *ps)
   // symbols into account.
   parse_state_list result = parse_state_list_new ();
   state_item_number si_next = si->trans;
-  // check for disabled transition, shouldn't happen
-  // as any state_items that lead to these should be
-  // disabled.
+  // Check for disabled transition, shouldn't happen as any
+  // state_items that lead to these should be disabled.
   if (si_next < 0)
     return result;
   parse_state *next_ps = copy_parse_state (false, ps);
@@ -594,8 +590,8 @@ print_parse_state (parse_state *ps)
   FILE *out = stderr;
   fprintf (out, "(size %zu depth %d rc %d)\n",
           ps->state_items.total_size, ps->depth, ps->reference_count);
-  print_state_item (ps->state_items.head_elt, out, "");
-  print_state_item (ps->state_items.tail_elt, out, "");
+  state_item_print (ps->state_items.head_elt, out, "");
+  state_item_print (ps->state_items.tail_elt, out, "");
   if (ps->derivs.total_size > 0)
     derivation_print (ps->derivs.head_elt, out, "");
   putc ('\n', out);
